@@ -89,11 +89,14 @@ def main():
     )
     parser.add_argument(
         "-o",
-        "--output-dir",
+        "--output",
         nargs='?',
         default='',
-        dest='output_dir',
-        help="Absolute path to where the optimized image will be stored at."
+        dest='output',
+        help="Either the absolute path to where the optimized image will be "
+             "stored at, or just the  optimized image filename. In case it is "
+             "not an absolute path we will assume it is a filename, and we "
+             "will store it at the same directory the original image is."
     )
 
     ## Now we can parse the arguments  ##########################################################################
@@ -166,18 +169,27 @@ def main():
             f'inner_error: {rejection_notice.inner_error}'
         )
     elif r.status == OptimizationResponseStatus.SUCCESS:
-        output_dir = os.path.dirname(
-            image_path)  # You can change that to any other directory.
-        base_filename, file_extension = os.path.splitext(image_path)
-        loop.run_until_complete(
-            store_file_content(
-                r.response_stream,
-                output_dir,
+        output = args.output
+        original_image_abs_path = os.path.abspath(os.path.dirname(image_path))
+        if output:
+            # Let's assume just the filename was set as output, and we then
+            # store it where the original image is.
+            if not os.path.isabs(output):
+                output = os.path.join(original_image_abs_path, output)
+        else:
+            base_filename, file_extension = os.path.splitext(image_path)
+            output_filename = '{}{}'.format(
                 base_filename,
-                precursor
+                constants.PrecursorToExtensionEnum[precursor.name].value
             )
+            output = os.path.join(
+                original_image_abs_path,
+                output_filename
+            )
+        loop.run_until_complete(
+            store_file_content(r.response_stream, output)
         )
-        print(f'Optimized image stored at: {output_dir}')
+        print(f'Optimized image stored at: {output}')
 
 
 if __name__ == '__main__':
