@@ -82,20 +82,9 @@ async def pass_and_compute_hash(stream: AsyncBufferedReader) -> OnePassInfo:
 async def store_file_content(
     stream: AsyncBufferedReader,
     output_path: str,
-    base_filename: str,
-    precursor: constants.PrecursorEnum
-) -> None:
-
-    optimized_filename = '{}{}'.format(
-        base_filename,
-        constants.PrecursorToExtensionEnum[precursor.name].value
-    )
-    optimized_path = os.path.join(
-        output_path,
-        optimized_filename
-    )
+) -> int:
     size = 0
-    with open(optimized_path, 'wb+') as f:
+    with open(output_path, 'wb+') as f:
         async for chunk in stream:
             f.write(chunk)
             size += len(chunk)
